.. Copyright (C) 2016 taylor.fish <contact@taylor.fish>

.. This file is part of pyrcb2-docs, documentation for pyrcb2.

.. pyrcb2-docs is licensed under the GNU Lesser General Public License
   as published by the Free Software Foundation, either version 3 of
   the License, or (at your option) any later version.

.. As an additional permission under GNU GPL version 3 section 7, you
   may distribute non-source forms of pyrcb2-docs without the copy of
   the GNU GPL normally required by section 4, provided you include a
   URL through which recipients can obtain a copy of the Corresponding
   Source and the GPL at no charge.

.. pyrcb2-docs is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

.. You should have received a copy of the GNU Lesser General Public License
   along with pyrcb2-docs.  If not, see <http://www.gnu.org/licenses/>.

.. currentmodule:: pyrcb2

Version 0.1
===========

Changelog
---------

.. _changelog-0.1.3:

0.1.3
~~~~~

* Fixed a bug where the default event loop would always be used when
  connecting (even when a different loop was specified).

.. _changelog-0.1.2:

0.1.2
~~~~~

* Moved documentation to `<https://pythonhosted.org/>`_, since Read the Docs
  doesn't support Python 3.5.

.. _changelog-0.1.1:

0.1.1
~~~~~

The first release of pyrcb2.
